@@ -173,7 +173,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                                                     if !ctx.start_transaction().await.is_ok() {
                                                         continue;
                                                     }
-                                                    let processing_result = process_handler(&mut ctx, &message.0).await;
+                                                    let processing_result = process_handler(&internal_ctx, &mut ctx, &message.0).await;
                                                     if !processing_result.is_ok() {
                                                         if !ctx.abort_transaction().await.is_ok() {
                                                             // just log the failure to abort tx
@@ -455,7 +455,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub async fn initiate_payment_endpoint(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
-                body: TypedBody<Option<<super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs>>,
+                body: TypedBody<<super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs>,
             ) -> Result<HttpResponseOk<Checkout>, HttpError> {
                 let path_params = path.into_inner();
                 let args = body.into_inner();
@@ -491,10 +491,14 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub async fn initiate_order_endpoint(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
-                body: TypedBody<Option<<super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs>>,
+                body: TypedBody<<super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs>,
             ) -> Result<HttpResponseOk<Checkout>, HttpError> {
                 let path_params = path.into_inner();
                 let args = body.into_inner();
+                let internal_ctx = req_ctx
+                    .context()
+                    .internal_context
+                    .clone();
                 let mut ctx = req_ctx
                     .context()
                     .context_provider
@@ -503,7 +507,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                     .unwrap();
 
                 ctx.start_transaction().await.unwrap();
-                match initiate_order_handler(&mut ctx, &path_params.id, args).await {
+                match initiate_order_handler(&internal_ctx, &mut ctx, &path_params.id, args).await {
                     Ok(co) => {
                         ctx.commit_transaction().await.unwrap();
                         Ok(HttpResponseOk(co))
@@ -629,6 +633,10 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
             >>, HttpError> {
                 let path_params = path.into_inner();
+                let internal_ctx = req_ctx
+                    .context()
+                    .internal_context
+                    .clone();
                 let mut ctx = req_ctx
                     .context()
                     .context_provider
@@ -637,7 +645,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                     .unwrap();
 
                 ctx.start_transaction().await.unwrap();
-                match cancel_handler(&mut ctx, &path_params.id).await {
+                match cancel_handler(&internal_ctx, &mut ctx, &path_params.id).await {
                     Ok(co) => {
                         ctx.commit_transaction().await.unwrap();
                         Ok(HttpResponseOk(co))
